## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 22;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# The gevent tests are automatically skipped when gevent is not installed.
# When bootstrapping new Python versions, gevent is often not available until
# very late. This bcond allows to ship zmq without gevent when needed.
%bcond gevent 1

Name:           python-zmq
Version:        22.3.0
Release:        %autorelease
Summary:        Python bindings for zeromq

# As noted in https://github.com/zeromq/pyzmq/blob/v26.2.0/RELICENSE/README.md:
#   pyzmq starting with 26.0.0 is fully licensed under the 3-clause Modified
#   BSD License. A small part of the core (Cython backend only) was previously
#   licensed under LGPLv3 for historical reasons. Permission has been granted
#   by the contributors of the vast majority of those components to relicense
#   under MPLv2 or BSD. This backend has been completely replaced in pyzmq 26,
#   and the new implementation is fully licensed under BSD-3-Clause, so pyzmq
#   is now under a single license.
# Since this package is currently at 22.3.0, the entire source is BSD-3-Clause
# (LICENSE.BSD), except:
#   - Some core files (the low-level Cython bindings) are LGPL-3.0-or-later
#     (LICENSE.LESSER); based on comments in file headers, this is:
#     * zmq/backend/cython/_device.pyx.
#     * zmq/include/zmq.h
#     * zmq/include/zmq_utils.h
#   - zmq/ssh/forward.py, which is derived from a Paramiko demo, is
#     LGPL-2.1-or-later
#   - The following are Apache-2.0:
#     * zmq/eventloop/minitornado/ioloop.py
#     * zmq/eventloop/minitornado/platform/auto.py
#     * zmq/eventloop/minitornado/platform/interface.py
#     * zmq/eventloop/minitornado/platform/posix.py
#     * zmq/eventloop/minitornado/stack_context.py
#     * zmq/eventloop/zmqstream.py
# Additionally, the following do not affect the license of the binary RPMs:
#   - tools/run_with_env.cmd is CC0-1.0; for distribution in the source RPM, it
#     is covered by “Existing uses of CC0-1.0 on code files in Fedora packages
#     prior to 2022-08-01, and subsequent upstream versions of those files in
#     those packages, continue to be allowed. We encourage Fedora package
#     maintainers to ask upstreams to relicense such files.”
#     https://gitlab.com/fedora/legal/fedora-license-data/-/issues/91#note_1151947383
#   - examples/device/device.py and examples/win32-interrupt/display.py are
#     LicenseRef-Fedora-Public-Domain; approved in “Review of
#     python-zmq examples dedicated to the public domain,”
#     https://gitlab.com/fedora/legal/fedora-license-data/-/issues/616; see
#     https://gitlab.com/fedora/legal/fedora-license-data/-/merge_requests/716
#   - The following are BSD-2-Clause, but are removed in %%prep:
#     * bundled/zeromq/external/wepoll/
#   - The following are LGPL-3.0-or-later, but are removed in %%prep:
#     * bundled/zeromq/, except bundled/zeromq/external/wepoll/
License:        %{shrink:
                BSD-3-Clause AND
                LGPL-3.0-or-later AND
                LGPL-2.1-or-later AND
                Apache-2.0
                }
URL:            https://zeromq.org/languages/python/
Source0:        %{pypi_source pyzmq}
# BUG: A file is licensed Apache-2.0, but the license text is not distributed
# https://github.com/zeromq/pyzmq/issues/2048
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt#/LICENSE.Apache-2.0

BuildRequires:  gcc
BuildRequires:  pkgconfig(libzmq)
BuildRequires:  python%{python3_pkgversion}-devel

%global common_description %{expand:
This package contains Python bindings for ZeroMQ. ØMQ is a lightweight and fast
messaging implementation.}

%description %{common_description}


%package -n python%{python3_pkgversion}-zmq
Summary:        %{summary}
%py_provides    python%{python3_pkgversion}-pyzmq

%description -n python%{python3_pkgversion}-zmq %{common_description}


%package -n python%{python3_pkgversion}-zmq-tests
Summary:        %{summary}, testsuite
# This subpackage does not contain any of the files that are under other
# licenses; see the comment above the main License tag.
License:        BSD-3-Clause

Requires:       python%{python3_pkgversion}-zmq%{?_isa} = %{version}-%{release}
%py_provides    python%{python3_pkgversion}-pyzmq-tests

# Tests in zmq/tests/mypy.py require mypy, but see:
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
#
# Some tests in zmq/tests/test_context.py and zmq/tests/test_socket.py require
# pyczmq, which is not packaged and has not been updated in a decade.
#
BuildRequires:  python%{python3_pkgversion}-pytest
Requires:       python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-tornado
Requires:       python%{python3_pkgversion}-tornado
# Enable more tests in zmq/tests/test_message.py:
BuildRequires:  python%{python3_pkgversion}-numpy
Requires:       python%{python3_pkgversion}-numpy
%if %{with gevent}
BuildRequires:  python%{python3_pkgversion}-gevent
Requires:       python%{python3_pkgversion}-gevent
%endif

%description -n python%{python3_pkgversion}-zmq-tests %{common_description}

This package contains the test suite for the Python bindings.


%prep
%autosetup -p1 -n pyzmq-%{version}

# remove bundled libraries
rm -rv bundled/

# Remove any Cython-generated .c files in order to regenerate them:
find zmq -name '*.c' -print -delete

# Remove shebangs from non-script sources. The find-then-modify pattern
# preserves mtimes on sources that did not need to be modified.
find 'src' -type f -name '*.py' \
    -exec gawk '/^#!/ { print FILENAME }; { nextfile }' '{}' '+' |
  xargs -r sed -r -i '1{/^#!/d}'

# BUG: A file is licensed Apache-2.0, but the license text is not distributed
# https://github.com/zeromq/pyzmq/issues/2048
cp -p '%{SOURCE1}' .


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l zmq


%check
# to avoid partially initialized zmq module from cwd
mkdir -p _empty
cd _empty
ln -s %{buildroot}%{python3_sitearch}/zmq/ ../pytest.ini ./

# test_draft seems to get incorrectly run:
# https://github.com/zeromq/pyzmq/issues/1853
k="${k-}${k+ and }not test_draft"

# Whatever it takes to build the Cython extension tests/cython_ext.pyx that is
# *in the tests*, we aren’t doing it. This goes away in later releases, so we
# don’t put any effort into figuring out how to make it work.
k="${k-}${k+ and }not test_cython"

%pytest -k "${k-}" -v -rs zmq/tests


%files -n python%{python3_pkgversion}-zmq -f %{pyproject_files}
%doc README.md
%exclude %{python3_sitearch}/zmq/tests/


%files -n python%{python3_pkgversion}-zmq-tests
%{python3_sitearch}/zmq/tests/


%changelog
## START: Generated by rpmautospec
* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-22
- Update comment about LicenseRef-Fedora-Public-Domain

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-21
- Make the dependency on python3-zmq from python3-zmq-tests arch-specific

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-19
- Align the gevent test dependency with the others

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-18
- Fix subpackage License fields

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-17
- Try to add appropriate dependencies to python3-zmq-tests

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-16
- Print reasons for skipped tests

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-15
- Tidy up %%prep

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-14
- Assert that .dist-info contains at leas one license file

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-12
- Write test skips one per line; respect pytest.ini

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-11
- Use simplified Summary and description from upstream

* Mon Nov 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 22.3.0-10
- Correct License and update to SPDX
- Ship an Apache-2.0 license file, and report its absence upstream

* Mon Nov 25 2024 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 22.3.0-7
- Fixed the ZeroMQ dependency

* Mon Nov 25 2024 Miro Hrončok <miro@hroncok.cz> - 22.3.0-6
- Remove old cruft

* Mon Nov 25 2024 Miro Hrončok <miro@hroncok.cz> - 22.3.0-5
- Run the tests

* Mon Nov 25 2024 Charalampos Stratakis <cstratak@redhat.com> - 22.3.0-4
- Convert to pyproject macros

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 22.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Nov 06 2021 Kevin Fenzi <kevin@scrye.com> - 22.3.0-1
- Update to 22.3.0. Fixes rhbz#2004837

* Sun Aug 08 2021 Kevin Fenzi <kevin@scrye.com> - 22.2.1-1
- Update to 22.2.1. Fixes rhbz#1989975

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 22.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Thu Jun 03 2021 Python Maint <python-maint@redhat.com> - 22.0.3-2
- Rebuilt for Python 3.10

* Fri Feb 12 2021 Kevin Fenzi <kevin@scrye.com> - 22.0.3-1
- Update to 22.0.3. Fixes rhbz#1928104

* Wed Feb 03 2021 Kevin Fenzi <kevin@scrye.com> - 22.0.2-1
- Update to 22.0.2. Fixes rhbz#1922110

* Thu Jan 28 2021 Kevin Fenzi <kevin@scrye.com> - 21.0.2-1
- Update to 21.0.2. Fixes rhbz#1920351

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 21.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Jan 16 2021 Kevin Fenzi <kevin@scrye.com> - 21.0.0-1
- Update to 21.0.0. Fixes rhbz#1916136

* Thu Dec 31 2020 Kevin Fenzi <kevin@scrye.com> - 20.0.0-1
- Update to 20.0.0. Fixes rhbz#1832893

* Tue Nov 24 2020 Joel Capitao <jcapitao@redhat.com> - 19.0.2-1
- Update to 19.0.2

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 19.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat May 23 2020 Miro Hrončok <mhroncok@redhat.com> - 19.0.0-2
- Rebuilt for Python 3.9

* Fri Apr 03 2020 Carl George <carl@george.computer> - 19.0.0-1
- Latest upstream rhbz#1772343

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 18.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Jan 14 2020 Jochen Breuer <jbreuer@suse.de> - 18.1.0-3
- Providing python-pyzmq, since some packages are still relying on that.
  See: https://bugzilla.redhat.com/show_bug.cgi?id=1789889

* Fri Nov 29 2019 Miro Hrončok <mhroncok@redhat.com> - 18.1.0-2
- Subpackages python2-zmq, python2-zmq-test have been removed
  See https://fedoraproject.org/wiki/Changes/RetirePython2

* Sun Oct 06 2019 Kevin Fenzi <kevin@scrye.com> - 18.1.0-1
- Update to 18.1.0. Fixes bug #1742606

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 18.0.2-4
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Fri Aug 16 2019 Miro Hrončok <mhroncok@redhat.com> - 18.0.2-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 18.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sun Jun 30 2019 Kevin Fenzi <kevin@scrye.com> - 18.0.2-1
- Update to 18.0.2. Fixes bug #1724706

* Mon Apr 29 2019 Kevin Fenzi <kevin@scrye.com> - 18.0.1-1
- Update to 18.0.1. Fixes bug #1601128

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 17.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 17.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Jun 17 2018 Miro Hrončok <mhroncok@redhat.com> - 17.0.0-2
- Rebuilt for Python 3.7

* Sat May 12 2018 Miro Hrončok <mhroncok@redhat.com> - 17.0.0-1
- Update to 17.0.0 (#1538381)
- Fix shebangs

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 16.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 31 2018 Iryna Shcherbina <ishcherb@redhat.com> - 16.0.2-6
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 16.0.2-2
- Rebuild for Python 3.6

* Wed Nov 23 2016 Kevin Fenzi <kevin@scrye.com> - 16.0.2-1
- Update to 16.0.2. Fixes bug #1397615

* Sun Nov 13 2016 Thomas Spura <tomspur@fedoraproject.org> - 16.0.1-1
- update to 16.0.1
- build twice (for installing and testing in-place)

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 15.3.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Jul 12 2016 Orion Poplawski <orion@cora.nwra.com> - 15.3.0-1
- Update to 15.3.0

* Tue Jul 12 2016 Orion Poplawski <orion@cora.nwra.com> - 14.7.0-7
- Use modern provides filtering

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 14.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 16 2015 Thomas Spura <tomspur@fedoraproject.org> - 14.7.0-5
- Use setupegg.py for building/installing to have an unzip'ed egg

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.7.0-4
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Fri Oct 16 2015 Thomas Spura <tomspur@fedoraproject.org> - 14.7.0-3
- rebuilt to pick up new obsoletes/provides

* Wed Oct 14 2015 Thomas Spura <tomspur@fedoraproject.org> - 14.7.0-2
- Use python_provide and py_build macros
- Cleanup spec

* Mon Jun 29 2015 Ralph Bean <rbean@redhat.com> - 14.7.0-2
- Support python34 on EPEL7.

* Tue Jun 23 2015 Thomas Spura <tomspur@fedoraproject.org> - 14.7.0-1
- update to 14.7.0
- temporarily disable python3 testsuite as it hangs on koji

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Nov 17 2014 Thomas Spura <tomspur@fedoraproject.org> - 14.4.1-1
- update to 14.4.1
- build against zeromq-4

* Wed Aug 27 2014 Thomas Spura <tomspur@fedoraproject.org> - 14.3.1-1
- update to 14.3.1

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 13.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 13.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 14 2014 Bohuslav Kabrda <bkabrda@redhat.com> - 13.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Mon Aug  5 2013 Thomas Spura <tomspur@fedoraproject.org> - 13.0.2-1
- update to new version (fixes FTBFS)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 13.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Mar 20 2013 Thomas Spura <tomspur@fedoraproject.org> - 13.0.0-1
- update to 13.0.0
- add BSD to license list

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Oct 15 2012 Thomas Spura <tomspur@fedoraproject.org> - 2.2.0.1-1
- update to 2.2.0.1
- move to BR zeromq3
- not all *.c files may be deleted, when receneration of .c files by Cython
- remove bundled folder explicitely

* Sat Aug 04 2012 David Malcolm <dmalcolm@redhat.com> - 2.2.0-5
- rebuild for https://fedoraproject.org/wiki/Features/Python_3.3

* Fri Aug  3 2012 David Malcolm <dmalcolm@redhat.com> - 2.2.0-4
- force regeneration of .c files by Cython (needed for python 3.3 support)

* Fri Aug  3 2012 David Malcolm <dmalcolm@redhat.com> - 2.2.0-3
- remove rhel logic from with_python3 conditional

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Apr 26 2012 Thomas Spura <tomspur@fedoraproject.org> - 2.2.0-1
- update to 2.2.0

* Wed Mar  7 2012 Thomas Spura <tomspur@fedoraproject.org> - 2.1.11-1
- update to new version

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Dec 14 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.1.9-3
- tests package requires main package
- filter python3 libs

* Thu Dec  8 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.1.9-2
- use proper buildroot macro
- don't include tests twice

* Wed Sep 21 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.1.9-1
- update to new version
- run testsuite on python3

* Sun Jul 31 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.1.4-2
- don't delete the tests, needed by ipython-tests on runtime
- don't use _sourcedir macro

* Wed Apr  6 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.1.4-1
- update to new version (#690199)

* Wed Mar 23 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.1.1-1
- update to new version (#682201)

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jan 30 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.0.10.1-1
- update to new version (fixes memory leak)
- no need to run 2to3 on python3 subpackage

* Thu Jan 13 2011 Thomas Spura <tomspur@fedoraproject.org> - 2.0.10-1
- update to new version
- remove patch (is upstream)
- run tests differently

* Wed Dec 29 2010 David Malcolm <dmalcolm@redhat.com> - 2.0.8-2
- rebuild for newer python3

* Thu Sep 23 2010 Thomas Spura <tomspur@fedoraproject.org> - 2.0.8-1
- update to new version to be comply with zeromp

* Sun Aug 22 2010 Thomas Spura <tomspur@fedoraproject.org> - 0.1.20100725git18f5d06-4
- rebuild with python3.2
  http://lists.fedoraproject.org/pipermail/devel/2010-August/141368.html

* Thu Aug  5 2010 Thomas Spura <tomspur@fedoraproject.org> - 0.1.20100725git18f5d06-3
- add missing BR for 2to3

* Tue Aug  3 2010 Thomas Spura <tomspur@fedoraproject.org> - 0.1.20100725git18f5d06-2
- build python3 subpackage
- rename to from pyzmq to python-zmq
- change license

* Sun Jul 25 2010 Thomas Spura <tomspur@fedoraproject.org> - 0.1.20100725git18f5d06-1
- renew git snapshot
- start from version 0.1 like upstream (not the version from zeromq)
- remove buildroot / %%clean

* Sat Jun 12 2010 Thomas Spura <tomspur@fedoraproject.org - 2.0.7-1
- initial package (based on upstreams example one)

## END: Generated by rpmautospec
